summaryrefslogtreecommitdiff
path: root/cui/source/inc/acccfg.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'cui/source/inc/acccfg.hxx')
-rw-r--r--cui/source/inc/acccfg.hxx17
1 files changed, 6 insertions, 11 deletions
diff --git a/cui/source/inc/acccfg.hxx b/cui/source/inc/acccfg.hxx
index 7d5ac47635d3..8935d1e726e6 100644
--- a/cui/source/inc/acccfg.hxx
+++ b/cui/source/inc/acccfg.hxx
@@ -87,7 +87,7 @@ public:
m_pAccelConfigPage( pAccelConfigPage )
{}
- void ReplaceEntry( USHORT nPos, const String &rStr );
+ void ReplaceEntry( sal_uInt16 nPos, const String &rStr );
};
// class SfxAcceleratorConfigPage ----------------------------------------
@@ -104,7 +104,7 @@ struct TAccInfo
, m_bIsConfigurable(sal_True )
, m_sCommand ( )
, m_aKey (aKey )
// its important to set TRUE as default -
// because only fix entries will be disabled later ...
{}
@@ -181,9 +181,7 @@ private:
String GetLabel4Command(const String& sCommand);
void InitAccCfg();
- KeyCode MapPosToKeyCode( USHORT nPos ) const;
- USHORT MapKeyCodeToPos( const KeyCode &rCode ) const;
- String GetFunctionName( KeyFuncType eType ) const;
+ sal_uInt16 MapKeyCodeToPos( const KeyCode &rCode ) const;
css::uno::Reference< css::frame::XModel > SearchForAlreadyLoadedDoc(const String& sName);
void StartFileDialog( WinBits nBits, const String& rTitle );
@@ -196,13 +194,10 @@ public:
SfxAcceleratorConfigPage( Window *pParent, const SfxItemSet& rItemSet );
virtual ~SfxAcceleratorConfigPage();
- virtual BOOL FillItemSet( SfxItemSet& );
+ virtual sal_Bool FillItemSet( SfxItemSet& );
virtual void Reset( const SfxItemSet& );
- void SelectMacro(const SfxMacroInfoItem*);
void Apply(const css::uno::Reference< css::ui::XAcceleratorConfiguration >& pAccMgr);
- void CopySource2Target(const css::uno::Reference< css::ui::XAcceleratorConfiguration >& xSourceAccMgr,
- const css::uno::Reference< css::ui::XAcceleratorConfiguration >& xTargetAccMgr);
static SfxTabPage* Create( Window* pParent, const SfxItemSet& rAttrSet );
};
@@ -216,8 +211,8 @@ public:
SfxAcceleratorConfigListBox( Window *pParent, ResId &rResId ) :
ListBox( pParent, rResId ) {}
- void ReplaceEntry( USHORT nPos, const String &rStr );
- void ExpandEntry ( USHORT nPos, const String &rStr );
+ void ReplaceEntry( sal_uInt16 nPos, const String &rStr );
+ void ExpandEntry ( sal_uInt16 nPos, const String &rStr );
};
class SvxShortcutAssignDlg : public SfxSingleTabDialog
@@ -104,7 +104,7 @@ struct TAccInfo
, m_sCommand ( )
, m_aKey (aKey )
- // its important to set TRUE as default -
+ // its important to set sal_True as default -
// because only fix entries will be disabled later ...
{}